@@ -142,7 +142,7 @@ class Model:
             if isinstance(getattr(table, field), QueryField):
                 sql_name = f'{table.table_short_name()}__{field}'
         except AttributeError:
-            if '::' not in field and '->' not in field:
+            if '::' not in field and '->' not in field and 'value between' in field.lower():
                 return [], []
 
         if isinstance(value, str):
@@ -315,16 +315,8 @@ class Model:
         if not postgres_uri:
             postgres_uri = os.getenv('DB_URL')
 
-        if not postgres_uri:
-            raise DatabaseError("No database connection URL was provided")
-
         try:
-            timeout = int(os.getenv("DB_TIMEOUT", 30))
-        except (TypeError, ValueError):
-            timeout = 30
-
-        try:
-            pool = await aiopg.create_pool(postgres_uri, timeout=timeout)
+            pool = await aiopg.create_pool(postgres_uri, timeout=10)
             async with pool.acquire() as connection:
                 async with connection.cursor(cursor_factory=psycopg2.extras.DictCursor) as cursor:
                     try:
@@ -490,7 +482,7 @@ class Model:
         return count.get('count')
 
     @classmethod
-    async def paginated(cls, parameters=None, sort_column=None, sort_order='asc', pagination=None):
+    async def all_with_pagination(cls, parameters=None, sort_column=None, sort_order='asc', pagination=None):
         query, params = cls._generate_sql()
         where, parameters = cls._process_parameters(parameters)
         parameters.update(params)
